macro_rules! debug_assert_valid {
($graph:expr, $stage:expr) => { ... };
}Expand description
Panic when verification fails. Debug builds only — in release this macro expands to nothing and is not compiled.
macro_rules! debug_assert_valid {
($graph:expr, $stage:expr) => { ... };
}Panic when verification fails. Debug builds only — in release this macro expands to nothing and is not compiled.